==> clocksn900_1.0.0-2.tar.gz: clocksn900-1.0.0/src/opt/clocksn900/clock.py <==
import pygame, random, time, math # import pygame
pygame.init() # enable pygame
pygame.display.set_caption("clock face N900") # set window title
pygame.mouse.set_visible(0) # dont show cursor
screen=pygame.display.set_mode([800,480],pygame.FULLSCREEN) # create a screen, to make it full screen use  screen=pygame.display.set_mode([480,800],pygame.FULLSCREEN)
clock_face=pygame.image.load("/opt/clocksn900/all.png").convert() # load in the paper image and cconvert to native color scheme
clock_face.set_colorkey((255,0,255)) #set the invisible color within the paper image, in this case purple
myfont=pygame.font.SysFont("arial",30)
file_string="200"
moves_current=0
moves_best=200
pop_up=1
time_passed=0
time_current=0
time_best=500
try :
	fo=open("/opt/clocksn900/clock.sav","rb+")
except IOError:
	fo=open("/opt/clocksn900/clock.sav","wb+")
	fo.write("200")
	fo.write("050")
	fo.close
else:	
	file_string=fo.read(3)
	moves_best=int(file_string)
	file_string=fo.read(3)
	time_best=int(file_string)
	fo.close()
#sound_in = pygame.mixer.Sound("in.wav")
#sound_out = pygame.mixer.Sound("out.wav")
pos=pygame.mouse.get_pos() # set the pos variable to the current mouse position (this is a tuple)
clock1=[0,1,2,3,4,5,6,7,8,9,10,11]
clock2=[0,11,10,9,8,7,6,5,4,3,2,1]
clock3=[0,0,0,0,0,0,0,0,0,0,0,0]
clock4=[0,0,0,0,0,0,0,0,0,0,0,0]
pins=0
rotate=1
move=0
xpos=0
ypos=0
rnd_it=1
#wind_speed = random.random()/2.5
mainloop = True # this variable tells the main loop whether to run or not
#tmppaper=pygame.transform.rotozoom(paper,0,.5)			
#tmppaper.set_colorkey((255,0,255)) #set the invisible color within the paper image, in this case purple
while mainloop: # while the mainloop variable is true do the following.
	if rnd_it:
		pins=15
		moves_current=0
		clock1[1]=int(random.random()*12)
		clock1[3]=int(random.random()*12)
		clock1[4]=int(random.random()*12)
		clock1[5]=int(random.random()*12)
		clock1[7]=int(random.random()*12)
		clock2[1]=int(random.random()*12)
		clock2[3]=int(random.random()*12)
		clock2[4]=int(random.random()*12)
		clock2[5]=int(random.random()*12)
		clock2[7]=int(random.random()*12)
		rnd_it=0
	for event in pygame.event.get():  # run through all the events in the pygame event queue
		if event.type == pygame.QUIT: # see if the close event has happened (clicked on x)
			mainloop = False # if it did, set the mainloop to False
		elif event.type == pygame.KEYDOWN: # see if a key hass been pressed
			if event.key == pygame.K_UP: # if a key was pressed, check to see if it was the UP arrow
				mainloop = False # if it was, set the mainloop to False
		elif event.type == pygame.MOUSEBUTTONDOWN: # check if the screen has been pressed (mouse/finger down)
			pos = pygame.mouse.get_pos() # set the pos variable to the current mouse position (this is a tuple)
			xpos=(pos[0]-75)/50
			ypos=(pos[1]-75)/50
			if ypos==0:
				if xpos==0:
					rotate=1
					move=1
				if xpos==4:
					rotate=1
					move=2
				if xpos==8:
					rotate=-1
					move=2
				if xpos==12:
					rotate=-1
					move=1
			if ypos==1:
				if xpos==1 or xpos==11:
					pins=pins^1		
				if xpos==3 or xpos==9:
					pins=pins^2		
			if xpos==6:
				if ypos==0: rnd_it=1
				if ypos==2: pop_up=1
				if ypos==4: mainloop=False
			if ypos==3:
				if xpos==1 or xpos==11:
					pins=pins^4		
				if xpos==3 or xpos==9:
					pins=pins^8		
			if ypos==4:
				if xpos==0:
					rotate=1
					move=3
				if xpos==4:
					rotate=1
					move=4
				if xpos==8:
					rotate=-1
					move=4
				if xpos==12:
					rotate=-1
					move=3
			
		elif event.type == pygame.MOUSEBUTTONUP: # check if the screen has been released (mouse/finger up)
			pos = pygame.mouse.get_pos() # set the pos variable to the current mouse position (this is a tuple)		
	screen.blit (clock_face,(0,0)) # blit the background image onto the screen
	if pins&1:
		screen.blit(clock_face,(138,138),((824,400),(24,24)))
		screen.blit(clock_face,(638,138),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(138,138),((800,400),(24,24)))
		screen.blit(clock_face,(638,138),((824,400),(24,24)))
	if pins&2:
		screen.blit(clock_face,(238,138),((824,400),(24,24)))
		screen.blit(clock_face,(538,138),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(238,138),((800,400),(24,24)))
		screen.blit(clock_face,(538,138),((824,400),(24,24)))
	if pins&4:
		screen.blit(clock_face,(138,238),((824,400),(24,24)))
		screen.blit(clock_face,(638,238),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(138,238),((800,400),(24,24)))
		screen.blit(clock_face,(638,238),((824,400),(24,24)))
	if pins&8:
		screen.blit(clock_face,(238,238),((824,400),(24,24)))
		screen.blit(clock_face,(538,238),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(238,238),((800,400),(24,24)))
		screen.blit(clock_face,(538,238),((824,400),(24,24)))
	clock3=[0,0,0,0,0,0,0,0,0,0,0,0]
	clock4=[0,0,0,0,0,0,0,0,0,0,0,0]
	time_current=time.time()
	if moves_current==0:
		time_passed=time_current
	if move: 
		moves_current+=1	
	if move==1:
		clock3[0]=rotate
		clock4[0]=rotate		
		if pins&1:
			clock3[1]=rotate
			clock3[3]=rotate
			clock3[4]=rotate
			if pins&2:
				clock3[2]=rotate
				clock4[2]=rotate
				clock3[5]=rotate
			if pins&4:
				clock3[6]=rotate
				clock4[6]=rotate
				clock3[7]=rotate
			if pins&8:	
				clock3[5]=rotate	
				clock3[7]=rotate	
				clock3[8]=rotate	
				clock4[8]=rotate	
		else:
			clock4[1]=rotate
			clock4[3]=rotate
			clock4[4]=rotate
			if not pins&2:
				clock4[2]=rotate
				clock3[2]=rotate
				clock4[5]=rotate
			if not pins&4:
				clock4[6]=rotate
				clock3[6]=rotate
				clock4[7]=rotate
			if not pins&8:	
				clock4[5]=rotate	
				clock4[7]=rotate	
				clock4[8]=rotate	
				clock3[8]=rotate	
	if move==2:
		clock1[2]+=rotate		
		clock2[2]-=rotate		
		if pins&2:
			clock3[1]=rotate
			clock3[4]=rotate
			clock3[5]=rotate
			if pins&1:
				clock3[0]=rotate
				clock4[0]=rotate
				clock3[3]=rotate
			if pins&8:
				clock3[8]=rotate
				clock4[8]=rotate
				clock3[7]=rotate
			if pins&4:	
				clock3[3]=rotate	
				clock3[7]=rotate	
				clock3[6]=rotate	
				clock4[6]=rotate	
		else:
			clock4[1]=rotate
			clock4[4]=rotate
			clock4[5]=rotate
			if not pins&1:
				clock4[0]=rotate
				clock3[0]=rotate
				clock4[3]=rotate
			if not pins&8:
				clock4[8]=rotate
				clock3[8]=rotate
				clock4[7]=rotate
			if not pins&4:	
				clock4[3]=rotate	
				clock4[7]=rotate	
				clock4[6]=rotate	
				clock3[6]=rotate	
	if move==3:
		clock1[6]+=rotate		
		clock2[6]-=rotate		
		if pins&4:
			clock3[3]=rotate
			clock3[4]=rotate
			clock3[7]=rotate
			if pins&1:
				clock3[0]=rotate
				clock4[0]=rotate
				clock3[1]=rotate
			if pins&8:
				clock3[8]=rotate
				clock4[8]=rotate
				clock3[5]=rotate
			if pins&2:	
				clock3[1]=rotate	
				clock3[5]=rotate	
				clock3[2]=rotate	
				clock4[2]=rotate	
		else:
			clock4[3]=rotate
			clock4[4]=rotate
			clock4[7]=rotate
			if not pins&1:
				clock4[0]=rotate
				clock3[0]=rotate
				clock4[1]=rotate
			if not pins&8:
				clock4[8]=rotate
				clock3[8]=rotate
				clock4[5]=rotate
			if not pins&2:	
				clock4[1]=rotate	
				clock4[5]=rotate	
				clock4[2]=rotate	
				clock3[2]=rotate	
	if move==4:
		clock1[8]+=rotate		
		clock2[8]-=rotate		
		if pins&8:
			clock3[5]=rotate
			clock3[4]=rotate
			clock3[7]=rotate
			if pins&2:
				clock3[2]=rotate
				clock4[2]=rotate
				clock3[1]=rotate
			if pins&4:
				clock3[6]=rotate
				clock4[6]=rotate
				clock3[3]=rotate
			if pins&1:	
				clock3[1]=rotate	
				clock3[3]=rotate	
				clock3[0]=rotate	
				clock4[0]=rotate	
		else:
			clock4[5]=rotate
			clock4[4]=rotate
			clock4[7]=rotate
			if not pins&2:
				clock4[2]=rotate
				clock3[2]=rotate
				clock4[1]=rotate
			if not pins&4:
				clock4[6]=rotate
				clock3[6]=rotate
				clock4[3]=rotate
			if not pins&1:	
				clock4[1]=rotate	
				clock4[3]=rotate	
				clock4[0]=rotate	
				clock3[0]=rotate	
	move=0
	for y in range(12):
		clock1[y]+=clock3[y]
		clock2[y]-=clock4[y]
		if clock1[y]<0: clock1[y]+=12
		if clock1[y]>11: clock1[y]-=12	
		if clock2[y]<0: clock2[y]+=12
		if clock2[y]>11: clock2[y]-=12	
	for y in xrange(3):	
		for x in range(3):
			clock=x+(y*3)			
			screen.blit(clock_face,((100*x)+50,(100*y)+50),(((100*clock1[clock]),480),(100,100)))			
			screen.blit(clock_face,((100*(2-x))+450,(100*y)+50),(((100*clock2[clock]),480),(100,100)))
	screen.blit (myfont.render("current moves %3d"%moves_current,0,(255,255,255)),(70,375))			
	screen.blit (myfont.render("best moves %3d"%moves_best,0,(255,255,255)),(480,375))			
	screen.blit (myfont.render("current time %3d"%(time_current-time_passed),0,(255,255,255)),(70,405))			
	screen.blit (myfont.render("best time %3d"%time_best,0,(255,255,255)),(480,405))			
	pygame.display.update() # redraw the screen
	if (clock1[0]+clock1[1]+clock1[2]+clock1[3]+clock1[4]+clock1[5]+clock1[6]+clock1[7]+clock1[8])==0:
		if (clock2[0]+clock2[1]+clock2[2]+clock2[3]+clock2[4]+clock2[5]+clock2[6]+clock2[7]+clock2[8])==0:
			pop_up=2
			if (time_current-time_passed) < time_best: time_best=time_current-time_passed
			if moves_current<moves_best: moves_best=moves_current
			rnd_it=1
			fo=open("/opt/clocksn900/clock.sav","wb+")
			file_string=str(moves_best)			
			if len(file_string)<3: file_string="0"+file_string			
			if len(file_string)<3: file_string="0"+file_string			
			file_string=fo.write(file_string)
			file_string=str(time_best)			
			if len(file_string)<3: file_string="0"+file_string			
			if len(file_string)<3: file_string="0"+file_string			
			file_string=fo.write(file_string)
			fo.close()
	if pop_up:
		pauseloop=True
		while pauseloop:
			time.sleep(.125)
			move+=1
			if move>11: move=0
			for event in pygame.event.get():  # run through all the events in the pygame event queue
				if event.type == pygame.MOUSEBUTTONDOWN: # check if the screen has been pressed (mouse/finger down)
					pauseloop=False
			for y in xrange(3):	
				for x in range(3):
					clock=x+(y*3)			
					screen.blit(clock_face,((100*x)+50,(100*y)+50),(((100*move),480),(100,100)))			
					screen.blit(clock_face,((100*(2-x))+450,(100*y)+50),(((100*move),480),(100,100)))
			screen.blit(clock_face,(200,120),((800,(pop_up-1)*200),(400,200)))			
			pygame.display.update() # redraw the screen
		move=0
		pop_up=0
	time.sleep(.125)

==> clocksn900_1.0.0-3.tar.gz: clocksn900-1.0.0/src/opt/clocksn900/clock.py <==
import pygame, random, time, math # import pygame
pygame.init() # enable pygame
pygame.display.set_caption("clock face N900") # set window title
pygame.mouse.set_visible(0) # dont show cursor
screen=pygame.display.set_mode([800,480],pygame.FULLSCREEN) # create a screen, to make it full screen use  screen=pygame.display.set_mode([480,800],pygame.FULLSCREEN)
clock_face=pygame.image.load("/opt/clocksn900/all.png").convert() # load in the paper image and cconvert to native color scheme
clock_face.set_colorkey((255,0,255)) #set the invisible color within the paper image, in this case purple
myfont=pygame.font.SysFont("arial",30)
file_string="200"
moves_current=0
moves_best=200
pop_up=1
time_passed=0
time_current=0
time_best=500
try :
	fo=open("/opt/clocksn900/clock.sav","rb+")
except IOError:
	fo=open("/opt/clocksn900/clock.sav","wb+")
	fo.write("200")
	fo.write("050")
	fo.close
else:	
	file_string=fo.read(3)
	moves_best=int(file_string)
	file_string=fo.read(3)
	time_best=int(file_string)
	fo.close()
#sound_in = pygame.mixer.Sound("in.wav")
#sound_out = pygame.mixer.Sound("out.wav")
pos=pygame.mouse.get_pos() # set the pos variable to the current mouse position (this is a tuple)
clock1=[0,1,2,3,4,5,6,7,8,9,10,11]
clock2=[0,11,10,9,8,7,6,5,4,3,2,1]
clock3=[0,0,0,0,0,0,0,0,0,0,0,0]
clock4=[0,0,0,0,0,0,0,0,0,0,0,0]
pins=0
rotate=1
move=0
xpos=0
ypos=0
rnd_it=1
#wind_speed = random.random()/2.5
mainloop = True # this variable tells the main loop whether to run or not
#tmppaper=pygame.transform.rotozoom(paper,0,.5)			
#tmppaper.set_colorkey((255,0,255)) #set the invisible color within the paper image, in this case purple
while mainloop: # while the mainloop variable is true do the following.
	if rnd_it:
		pins=15
		moves_current=0
		clock1[1]=int(random.random()*12)
		clock1[3]=int(random.random()*12)
		clock1[4]=int(random.random()*12)
		clock1[5]=int(random.random()*12)
		clock1[7]=int(random.random()*12)
		clock2[1]=int(random.random()*12)
		clock2[3]=int(random.random()*12)
		clock2[4]=int(random.random()*12)
		clock2[5]=int(random.random()*12)
		clock2[7]=int(random.random()*12)
		rnd_it=0
	for event in pygame.event.get():  # run through all the events in the pygame event queue
		if event.type == pygame.QUIT: # see if the close event has happened (clicked on x)
			mainloop = False # if it did, set the mainloop to False
		elif event.type == pygame.KEYDOWN: # see if a key hass been pressed
			if event.key == pygame.K_UP: # if a key was pressed, check to see if it was the UP arrow
				mainloop = False # if it was, set the mainloop to False
		elif event.type == pygame.MOUSEBUTTONDOWN: # check if the screen has been pressed (mouse/finger down)
			pos = pygame.mouse.get_pos() # set the pos variable to the current mouse position (this is a tuple)
			xpos=(pos[0]-75)/50
			ypos=(pos[1]-75)/50
			if ypos==0:
				if xpos==0:
					rotate=1
					move=1
				if xpos==4:
					rotate=1
					move=2
				if xpos==8:
					rotate=-1
					move=2
				if xpos==12:
					rotate=-1
					move=1
			if ypos==1:
				if xpos==1 or xpos==11:
					pins=pins^1		
				if xpos==3 or xpos==9:
					pins=pins^2		
			if xpos==6:
				if ypos==0: rnd_it=1
				if ypos==2: pop_up=1
				if ypos==4: mainloop=False
			if ypos==3:
				if xpos==1 or xpos==11:
					pins=pins^4		
				if xpos==3 or xpos==9:
					pins=pins^8		
			if ypos==4:
				if xpos==0:
					rotate=1
					move=3
				if xpos==4:
					rotate=1
					move=4
				if xpos==8:
					rotate=-1
					move=4
				if xpos==12:
					rotate=-1
					move=3
			
		elif event.type == pygame.MOUSEBUTTONUP: # check if the screen has been released (mouse/finger up)
			pos = pygame.mouse.get_pos() # set the pos variable to the current mouse position (this is a tuple)		
	screen.blit (clock_face,(0,0)) # blit the background image onto the screen
	if pins&1:
		screen.blit(clock_face,(138,138),((824,400),(24,24)))
		screen.blit(clock_face,(638,138),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(138,138),((800,400),(24,24)))
		screen.blit(clock_face,(638,138),((824,400),(24,24)))
	if pins&2:
		screen.blit(clock_face,(238,138),((824,400),(24,24)))
		screen.blit(clock_face,(538,138),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(238,138),((800,400),(24,24)))
		screen.blit(clock_face,(538,138),((824,400),(24,24)))
	if pins&4:
		screen.blit(clock_face,(138,238),((824,400),(24,24)))
		screen.blit(clock_face,(638,238),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(138,238),((800,400),(24,24)))
		screen.blit(clock_face,(638,238),((824,400),(24,24)))
	if pins&8:
		screen.blit(clock_face,(238,238),((824,400),(24,24)))
		screen.blit(clock_face,(538,238),((800,400),(24,24)))
	else:
		screen.blit(clock_face,(238,238),((800,400),(24,24)))
		screen.blit(clock_face,(538,238),((824,400),(24,24)))
	clock3=[0,0,0,0,0,0,0,0,0,0,0,0]
	clock4=[0,0,0,0,0,0,0,0,0,0,0,0]
	time_current=time.time()
	if moves_current==0:
		time_passed=time_current
	if move: 
		moves_current+=1	
	if move==1:
		clock3[0]=rotate
		clock4[0]=rotate		
		if pins&1:
			clock3[1]=rotate
			clock3[3]=rotate
			clock3[4]=rotate
			if pins&2:
				clock3[2]=rotate
				clock4[2]=rotate
				clock3[5]=rotate
			if pins&4:
				clock3[6]=rotate
				clock4[6]=rotate
				clock3[7]=rotate
			if pins&8:	
				clock3[5]=rotate	
				clock3[7]=rotate	
				clock3[8]=rotate	
				clock4[8]=rotate	
		else:
			clock4[1]=rotate
			clock4[3]=rotate
			clock4[4]=rotate
			if not pins&2:
				clock4[2]=rotate
				clock3[2]=rotate
				clock4[5]=rotate
			if not pins&4:
				clock4[6]=rotate
				clock3[6]=rotate
				clock4[7]=rotate
			if not pins&8:	
				clock4[5]=rotate	
				clock4[7]=rotate	
				clock4[8]=rotate	
				clock3[8]=rotate	
	if move==2:
		clock1[2]+=rotate		
		clock2[2]-=rotate		
		if pins&2:
			clock3[1]=rotate
			clock3[4]=rotate
			clock3[5]=rotate
			if pins&1:
				clock3[0]=rotate
				clock4[0]=rotate
				clock3[3]=rotate
			if pins&8:
				clock3[8]=rotate
				clock4[8]=rotate
				clock3[7]=rotate
			if pins&4:	
				clock3[3]=rotate	
				clock3[7]=rotate	
				clock3[6]=rotate	
				clock4[6]=rotate	
		else:
			clock4[1]=rotate
			clock4[4]=rotate
			clock4[5]=rotate
			if not pins&1:
				clock4[0]=rotate
				clock3[0]=rotate
				clock4[3]=rotate
			if not pins&8:
				clock4[8]=rotate
				clock3[8]=rotate
				clock4[7]=rotate
			if not pins&4:	
				clock4[3]=rotate	
				clock4[7]=rotate	
				clock4[6]=rotate	
				clock3[6]=rotate	
	if move==3:
		clock1[6]+=rotate		
		clock2[6]-=rotate		
		if pins&4:
			clock3[3]=rotate
			clock3[4]=rotate
			clock3[7]=rotate
			if pins&1:
				clock3[0]=rotate
				clock4[0]=rotate
				clock3[1]=rotate
			if pins&8:
				clock3[8]=rotate
				clock4[8]=rotate
				clock3[5]=rotate
			if pins&2:	
				clock3[1]=rotate	
				clock3[5]=rotate	
				clock3[2]=rotate	
				clock4[2]=rotate	
		else:
			clock4[3]=rotate
			clock4[4]=rotate
			clock4[7]=rotate
			if not pins&1:
				clock4[0]=rotate
				clock3[0]=rotate
				clock4[1]=rotate
			if not pins&8:
				clock4[8]=rotate
				clock3[8]=rotate
				clock4[5]=rotate
			if not pins&2:	
				clock4[1]=rotate	
				clock4[5]=rotate	
				clock4[2]=rotate	
				clock3[2]=rotate	
	if move==4:
		clock1[8]+=rotate		
		clock2[8]-=rotate		
		if pins&8:
			clock3[5]=rotate
			clock3[4]=rotate
			clock3[7]=rotate
			if pins&2:
				clock3[2]=rotate
				clock4[2]=rotate
				clock3[1]=rotate
			if pins&4:
				clock3[6]=rotate
				clock4[6]=rotate
				clock3[3]=rotate
			if pins&1:	
				clock3[1]=rotate	
				clock3[3]=rotate	
				clock3[0]=rotate	
				clock4[0]=rotate	
		else:
			clock4[5]=rotate
			clock4[4]=rotate
			clock4[7]=rotate
			if not pins&2:
				clock4[2]=rotate
				clock3[2]=rotate
				clock4[1]=rotate
			if not pins&4:
				clock4[6]=rotate
				clock3[6]=rotate
				clock4[3]=rotate
			if not pins&1:	
				clock4[1]=rotate	
				clock4[3]=rotate	
				clock4[0]=rotate	
				clock3[0]=rotate	
	move=0
	for y in range(12):
		clock1[y]+=clock3[y]
		clock2[y]-=clock4[y]
		if clock1[y]<0: clock1[y]+=12
		if clock1[y]>11: clock1[y]-=12	
		if clock2[y]<0: clock2[y]+=12
		if clock2[y]>11: clock2[y]-=12	
	for y in xrange(3):	
		for x in range(3):
			clock=x+(y*3)			
			screen.blit(clock_face,((100*x)+50,(100*y)+50),(((100*clock1[clock]),480),(100,100)))			
			screen.blit(clock_face,((100*(2-x))+450,(100*y)+50),(((100*clock2[clock]),480),(100,100)))
	screen.blit (myfont.render("current moves %3d"%moves_current,0,(255,255,255)),(70,375))			
	screen.blit (myfont.render("best moves %3d"%moves_best,0,(255,255,255)),(480,375))			
	screen.blit (myfont.render("current time %3d"%(time_current-time_passed),0,(255,255,255)),(70,405))			
	screen.blit (myfont.render("best time %3d"%time_best,0,(255,255,255)),(480,405))			
	pygame.display.update() # redraw the screen
	if (clock1[0]+clock1[1]+clock1[2]+clock1[3]+clock1[4]+clock1[5]+clock1[6]+clock1[7]+clock1[8])==0:
		if (clock2[0]+clock2[1]+clock2[2]+clock2[3]+clock2[4]+clock2[5]+clock2[6]+clock2[7]+clock2[8])==0:
			pop_up=2
			if (time_current-time_passed) < time_best: time_best=time_current-time_passed
			if moves_current<moves_best: moves_best=moves_current
			rnd_it=1
			fo=open("/opt/clocksn900/clock.sav","wb+")
                        fo.write("%03d" % (moves_best))
                        fo.write("%03d" % (time_best))
			fo.close()
	if pop_up:
		pauseloop=True
		while pauseloop:
			time.sleep(.125)
			move+=1
			if move>11: move=0
			for event in pygame.event.get():  # run through all the events in the pygame event queue
				if event.type == pygame.MOUSEBUTTONDOWN: # check if the screen has been pressed (mouse/finger down)
					pauseloop=False
			for y in xrange(3):	
				for x in range(3):
					clock=x+(y*3)			
					screen.blit(clock_face,((100*x)+50,(100*y)+50),(((100*move),480),(100,100)))			
					screen.blit(clock_face,((100*(2-x))+450,(100*y)+50),(((100*move),480),(100,100)))
			screen.blit(clock_face,(200,120),((800,(pop_up-1)*200),(400,200)))			
			pygame.display.update() # redraw the screen
		move=0
		pop_up=0
	time.sleep(.125)
